@@ -159,6 +159,8 @@ has _comments => (
     },
 );
 
+=head1 CHILD METHODS
+
 =head2 regex
 
 Regex used to scan a line of config text, which then spawns an
@@ -195,26 +197,6 @@ sub _build__filehandle {
     return $file->openr;
 }
 
-=head2 filename_callback
-
-Callback for changing file paths when include files are on different relative paths.
-
-    # here is an example:
-    my $cb = sub {
-        my $file = shift;
-        print "We're in callback and file is $file\n";
-        if ($file =~ /catphotos/) {
-            return "/dog.conf";
-        }
-    };
-
-=cut
-
-has filename_callback => (
-    is => 'rw',
-    isa => 'CodeRef',
-);
-
 
 =head1 METHODS
 
@@ -243,6 +225,26 @@ sub BUILD {
     }
 }
 
+=head2 filename_callback
+
+Callback for changing file paths when include files are on different relative paths.
+
+    # here is an example:
+    my $cb = sub {
+        my $file = shift;
+        print "We're in callback and file is $file\n";
+        if ($file =~ /catphotos/) {
+            return "/dog.conf";
+        }
+    };
+
+=cut
+
+has filename_callback => (
+    is => 'rw',
+    isa => 'CodeRef',
+);
+
 =head2 parse
 
 Will read a line of the time from the current config
@@ -285,6 +287,12 @@ sub parse {
                 push @comments, $1;
                 next LINE;
             }
+            # lines with statements and comment, reprocess the statement and add the comment to comments array
+            if($line =~ /^(.*)\s*\#\s*(.*)/) {
+                push @comments, $2;
+                push @{$linebuf}, $1;
+                next LINE;
+            }
 
             # after semicolon or braces if there isn't a semicolon or return insert a newline
             if ($line =~ s/([;\{\}])([^;\n\r])/$1\n$2/g) {
